# Generated by roxygen2: do not edit by hand

S3method(check_identification,dsge_bayes)
S3method(check_identification,dsge_fit)
S3method(coef,dsge_bayes)
S3method(coef,dsge_fit)
S3method(fitted,dsge_fit)
S3method(forecast,dsge_fit)
S3method(geweke_test,dsge_bayes)
S3method(irf,default)
S3method(irf,dsge_bayes)
S3method(logLik,dsge_fit)
S3method(marginal_likelihood,dsge_bayes)
S3method(mcmc_diagnostics,dsge_bayes)
S3method(model_covariance,dsge_bayes)
S3method(model_covariance,dsge_fit)
S3method(model_covariance,dsge_solution)
S3method(nobs,dsge_fit)
S3method(parameter_sensitivity,dsge_bayes)
S3method(parameter_sensitivity,dsge_fit)
S3method(plot,dsge_bayes)
S3method(plot,dsge_decomposition)
S3method(plot,dsge_forecast)
S3method(plot,dsge_identification)
S3method(plot,dsge_irf)
S3method(plot,dsge_occbin)
S3method(plot,dsge_perfect_foresight)
S3method(plot,dsge_ppc)
S3method(plot,dsge_prior_posterior)
S3method(plot,dsge_sensitivity)
S3method(plot,dsge_smoothed)
S3method(posterior_predictive,dsge_bayes)
S3method(predict,dsge_fit)
S3method(prediction_accuracy,dsge_fit)
S3method(prediction_interval,dsge_fit)
S3method(print,dsge_bayes)
S3method(print,dsge_covariance)
S3method(print,dsge_decomposition)
S3method(print,dsge_fit)
S3method(print,dsge_forecast)
S3method(print,dsge_geweke)
S3method(print,dsge_identification)
S3method(print,dsge_irf)
S3method(print,dsge_marginal_likelihood)
S3method(print,dsge_matrix_result)
S3method(print,dsge_mcmc_summary)
S3method(print,dsge_model)
S3method(print,dsge_occbin)
S3method(print,dsge_perfect_foresight)
S3method(print,dsge_ppc)
S3method(print,dsge_prediction_accuracy)
S3method(print,dsge_prediction_interval)
S3method(print,dsge_prior)
S3method(print,dsge_prior_posterior)
S3method(print,dsge_robust_vcov)
S3method(print,dsge_sensitivity)
S3method(print,dsge_smoothed)
S3method(print,dsge_smoothed_shocks)
S3method(print,dsge_solution)
S3method(print,dsge_stability)
S3method(print,dsgenl_model)
S3method(print,dsgenl_steady_state)
S3method(prior_posterior_update,dsge_bayes)
S3method(residuals,dsge_fit)
S3method(robust_vcov,dsge_fit)
S3method(shock_decomposition,dsge_bayes)
S3method(shock_decomposition,dsge_fit)
S3method(smooth_shocks,dsge_bayes)
S3method(smooth_shocks,dsge_fit)
S3method(smooth_states,dsge_bayes)
S3method(smooth_states,dsge_fit)
S3method(steady_state,dsgenl_model)
S3method(summary,dsge_bayes)
S3method(summary,dsge_covariance)
S3method(summary,dsge_fit)
S3method(summary,dsge_occbin)
S3method(summary,dsge_perfect_foresight)
S3method(vcov,dsge_fit)
export(E)
export(bayes_dsge)
export(check_identification)
export(dsge_model)
export(dsgenl_model)
export(estimate)
export(forecast)
export(geweke_test)
export(irf)
export(irf_2nd_order)
export(lead)
export(linearize)
export(marginal_likelihood)
export(mcmc_diagnostics)
export(model_covariance)
export(obc_constraint)
export(obs)
export(parameter_sensitivity)
export(perfect_foresight)
export(policy_matrix)
export(posterior_predictive)
export(prediction_accuracy)
export(prediction_interval)
export(prior)
export(prior_posterior_update)
export(robust_vcov)
export(shock_decomposition)
export(simulate_2nd_order)
export(simulate_occbin)
export(smooth_shocks)
export(smooth_states)
export(solve_dsge)
export(stability)
export(state)
export(steady_state)
export(transition_matrix)
export(unobs)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,barplot)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(numDeriv,hessian)
importFrom(numDeriv,jacobian)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,is.ts)
importFrom(stats,logLik)
importFrom(stats,nobs)
importFrom(stats,optim)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,ts)
importFrom(stats,vcov)
importFrom(utils,head)
